@@ -154,8 +154,11 @@ class ApiList(View):
                 constants.URL_PARAM_DISPLAY_MODE, constants.DISPLAY_MODE_TABLE)
 
             if display_mode == constants.DISPLAY_MODE_STORY:
-                story = ar.actor.as_story(None, ar)
-                rows = [{'id': obj.pk} for obj in ar.sliced_data_iterator]
+                story = ""
+                rows = []
+                for obj in ar.sliced_data_iterator:
+                    story += obj.as_story_item(ar)
+                    rows.append({'id': obj.pk})
             else:
                 story = None
                 def serialize(ar, row):
